#
# spec file for package nlopt
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nlopt
Version:        2.4.2
Release:        lp150.1.11
Summary:        A library for nonlinear optimization
License:        LGPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://ab-initio.mit.edu/wiki/index.php/NLopt
Source0:        http://ab-initio.mit.edu/nlopt/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nlopt-2.3-pkgconfig.patch
Patch1:         nlopt-2.3-pkgconfig.patch
# PATCH-FIX-UPSTREAM pythondir.patch
Patch2:         pythondir.patch
# PATCH-FIX-UPSTREAM nlopt-octave-4.0.patch -- https://github.com/stevengj/nlopt/issues/33
Patch3:         nlopt-octave-4.0.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
BuildRequires:  pkgconfig
BuildRequires:  python-numpy-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package     -n lib%{name}0
Summary:        A library for nonlinear optimization
Group:          System/Libraries

%description -n lib%{name}0
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}0 = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package     -n python-%{name}
Summary:        Python interface to nonlinear optimization libray
Group:          Development/Libraries/Python
Requires:       python-numpy

%description -n python-%{name}
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains Python interface to NLopt library.

%package     -n octave-nlopt_optimize
Summary:        Octave interface to nonlinear optimization libray
Group:          Productivity/Scientific/Math
%requires_eq  octave-cli

%description -n octave-nlopt_optimize
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains Octave interface to NLopt library.

%prep
%setup -q
%patch1
%patch2 -p1
%patch3 -p1

%build
%configure --enable-shared \
           --disable-static
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot} -name '*.la' -exec rm -f {} ';'
%fdupes %{buildroot}%{py_sitedir}

%post -n lib%{name}0 -p /sbin/ldconfig

%postun -n lib%{name}0 -p /sbin/ldconfig

%files -n lib%{name}0
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README TODO
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/%{name}.*

%files -n python-%{name}
%defattr(-,root,root,-)
%doc COPYING
%{python_sitearch}/*

%files -n octave-nlopt_optimize
%defattr(-,root,root,-)
%doc COPYING
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%{_datadir}/octave/*/site/m/*

%changelog
* Thu Jun 23 2016 badshah400@gmail.com
- Use %%requires_eq octave-cli instead of Requires, octave installs
  its files to versioned dirs, so it is important for nlopt to
  be rebuilt for every version update of octave. Making the
  Requires version dependent achieves this.
* Tue Nov 17 2015 dmitry_r@opensuse.org
- Fix compatibility with Octave 4.0
  * nlopt-octave-4.0.patch
* Sun May 31 2015 dmitry_r@opensuse.org
- Disable Octave module due to incompatibility with Octave 4.0
* Thu Nov 13 2014 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Bugfix release, see included NEWS file for details.
- Update package descriptionts.
* Tue Feb 11 2014 badshah400@gmail.com
- Update to version 2.4.1
  - No Linux relevant changes from version 2.4.0
- Changes from version 2.4.0:
  + New genetic algorithm ESCH
  + Fix swig dir for VPATH builds
  + Use python-config program in the configure script to find the
    include directories for Python, if possible (may be overridden
    by PYTHON_CONFIG environment variable)
  + Bugfix in copy constructor for C++ and Python interfaces
  + Bugfix in return value for setting min/max objective
  + Handle negative rescalings in COBYLA and BOBYQA
  + Plugin installation honors the configure --prefix, if any
  + Various compilation fixes for compatibility with recent
    software
- Packaging changes:
  + Minor rebase of pythondir.patch
  + Drop nlopt-2.3-no-return-in-nonvoid-function.patch: corrected
    upstream.
* Tue Sep 10 2013 dvaleev@suse.com
- install python parts to sitearch (pythondir.patch)
* Wed Jun 12 2013 tchvatal@suse.com
- Add fix for .pc file so we can use this library even
  with other projects.
  * nlopt-2.3-pkgconfig.patch
* Sun Feb 24 2013 scorot@free.fr
- remove %%%%clean section
- add minimal single-line comment in spec file for patch0
- add files on %%%%doc section
- spec file cleanup
- add python(abi) requirements recent recent products
- update source url
* Sun Aug 19 2012 scorot@free.fr
- again fix build on x86_64
* Sun Aug 19 2012 scorot@free.fr
- fix build on x86_64
- fix package group names
* Sun Aug 19 2012 scorot@free.fr
- first package
